@@ -1,10 +1,10 @@
 """Module for type hints of xarray DataArray.
 
 This module provides type hints of xarray DataArray
-and is intended to be used other modules of the package.
+which are intended to be used other modules of the package.
 
 """
-__all__ = ["Dims", "Dtype", "Shape", "Name", "Attrs"]
+__all__ = ["Attrs", "Dims", "Dtype", "Name", "Shape"]
 
 
 # standard library
